# Sparse Autoencoder (SAE) API

Sparse Autoencoders, training, concepts, and related modules for mechanistic interpretability.

## Core SAE Classes

::: mi_crow.mechanistic.sae.sae.Sae

::: mi_crow.mechanistic.sae.modules.topk_sae.TopKSae

::: mi_crow.mechanistic.sae.autoencoder_context.AutoencoderContext

## Training

::: mi_crow.mechanistic.sae.sae_trainer.SaeTrainer

::: mi_crow.mechanistic.sae.sae_trainer.SaeTrainingConfig

::: mi_crow.mechanistic.sae.modules.topk_sae.TopKSaeTrainingConfig

## Concepts

::: mi_crow.mechanistic.sae.concepts.autoencoder_concepts.AutoencoderConcepts

::: mi_crow.mechanistic.sae.concepts.concept_dictionary.ConceptDictionary

::: mi_crow.mechanistic.sae.concepts.concept_models

::: mi_crow.mechanistic.sae.concepts.input_tracker.InputTracker

## Training Utilities

::: mi_crow.mechanistic.sae.training.wandb_logger.WandbLogger

